==> spip_4.0.4.orig.tar.xz: plugins-dist/mots/lang/mots_fon.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mots?lang_cible=fon
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_conseil_selection_mot_cle' => 'gbɛta daxo :do ta ji ɔ, e nyɔ nu mi na cyan xota lɛ do gbɛ é lɔ mɛ',

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'titotɔ gblogbloji ɔ tɔn ',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'wiwlantɔ lɛ̂',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'Jonɔbatɔ gblogbloji ɔ tɔn whénu yé nɔ sɛ wɛn ɖo agun ɔ mɛ ɔ',

	// I
	'icone_creation_groupe_mots' => 'Mi ɖè àgùn wěkwin yɔyɔ dévó tɔn ',
	'icone_creation_mots_cles' => 'Mi ɖè gbètakɛn yɔyɔ dévó tɔn ',
	'icone_modif_groupe_mots' => 'mi vɔ ɖyɔ xóxòkplé lɛ',
	'icone_mots_cles' => 'gbètákɛn',
	'icone_supprimer_groupe_mots' => 'gbìɖí gbɛtá lɛ',
	'icone_voir_tous_mots_cles' => 'Mi kpɔn gbètákɛn lɛ bí',
	'info_articles_lies_mot' => 'wěmà é cáɖó àlɔ zíntɛn é lɔ lɛ wú',
	'info_changer_nom_groupe' => 'mi ɖyɔ nyíkɔ gbɛtá ɔ tɔn:',
	'info_creation_mots_cles' => 'mi bló bó sɔ gbètɛn lɛ sín àfɔɖóté',
	'info_dans_groupe' => 'ɖò àgun ɔ mɛ:',
	'info_delet_mots_cles' => 'àzán gùdó tɔn ', # MODIF
	'info_groupe_important' => 'Agùn trítrí',
	'info_mots_cles' => 'Gbètákɛn',
	'info_mots_cles_association' => 'Yè hɛn ɔ yè ná cá Gbètákɛn é lɔ àgùn élɔ mɛ ɔ :',
	'info_oui_suppression_mot_cle' => 'ŋ jó ná súnsún gbètákɛn bísésé.',
	'info_question_mots_cles' => 'Mi jó ná zán gbètákɛn à ?',
	'info_qui_attribue_mot_cle' => 'yé siwú sɔ gbètákɛn àgùn é lɔ tɔn ɖó :',
	'info_retirer_mot' => 'ɖè wékwí é lɔ sín ',
	'info_retirer_mots' => 'Mi ɖè wékwí bí sín ',
	'info_rubriques_liees_mot' => 'àkpáxwé lɛ ɖê bɔɖó gbètákɛn lɛ wú ɔ',
	'info_selection_un_seul_mot_cle' => 'Mi gbètákɛn ɖòkpó jɛn mi síwú zé.', # MODIF
	'info_supprimer_mot' => 'gbìdí  ɔ wékwín é lɔ ',
	'info_titre_mot_cle' => 'nyíkɔ xótá ɔ kàbí gbètákɛn ɔ tɔn ',
	'info_un_mot' => 'xókwín ɖòkpó',
	'item_ajout_mots_cles' => 'Mi sɔ gbètakɛn lɛ gɔná',
	'item_non_ajout_mots_cles' => 'mi má sɔ zán xógbè lɛ ɖò kplékplé ɔ mɛ wó',
	'item_non_utiliser_config_groupe_mots_cles' => 'mi vlɔn kàn nú bìbà sɔ yí Gblògblòjí bàɖémɛ jí ',
	'item_non_utiliser_mots_cles' => 'mi má zán gbètákɛn lɛ o',
	'item_utiliser_config_groupe_mots_cles' => 'mi zán xó kléwún lɛ',
	'item_utiliser_mots_cles' => 'mi zán xó kléwún lɛ',

	// L
	'logo_mot_cle' => 'sɔsí xógbè ɔ tɔn',

	// T
	'texte_config_groupe_mots_cles' => ' xógbè lɛ nyɔwlántɔ lɛ gblogblojí é lɔ nɔ zɔn bɔ mi nɔ sɛ  wɛn ɖó bó nɔ lɛ yí wɛnxó kléwun lɛ wěmà kléwún ɖé lɛ wɛbɔ yé nɔ zɔn bɔ xó lɛ nɔ yí àtɛjí gànmɛgànmɛmi sɔ xóxòkplégbàví mi tɔn ', # MODIF
	'texte_mots_cles' => 'Gbêgbè yé wlán wěmà ɔMi sɔ Azán ɖê yé sɔ wěmà sɔ xlɛàlɔwlí ɖévó lɛ ɖê gòsín gblogblojí é lɔ ján mi tìnmɛ càcàcàxójíjlá ɔmi sɔ ɖidé ɖó wěmà lɛ mɛsùpípù tɔn nú mi ná tò wěmà mi tɔn gànjí ɔ mi síwú zán kwín é lɔ lɛmi kó mɔ mi àmɔ mi sɔ ɖò xóxòkplégbàví ɔ mɛ ámi lɛ vɔ yí kànjí',
	'texte_mots_cles_dans_forum' => 'Gbêgbè yé wlán wěmà ɔMi sɔ Azán ɖê yé sɔ wěmà sɔ xlɛàlɔwlí ɖévó lɛ ɖê gòsín gblogblojí é lɔ ján mi tìnmɛ càcàcàxójíjlá ɔmi sɔ ɖidé ɖó wěmà lɛ mɛsùpípù tɔn nú mi ná tò wěmà mi tɔn gànjí ɔ mi síwú zán kwín é lɔ lɛ',
	'texte_nouveau_mot' => 'wékwín yɔyɔ',
	'titre_config_groupe_mots_cles' => 'tò gbètàkɛnxópklélɛ ',
	'titre_gauche_mots_edit' => 'Numɛló wěkwín ɔ tɔn :',
	'titre_mots_cles_dans_forum' => 'gbètákɛn é ɖò kplékplé gblogblojí ɔ tɔn mɛ',
	'titre_mots_tous' => 'gbètákɛn lɛ',
	'titre_nouveau_groupe' => 'àgùn yɔyɔ',
	'titre_page_mots_tous' => 'gbètákɛn'
);

==> spip_4.4.6+dfsg.orig.tar.xz: plugins-dist/mots/lang/mots_fon.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mots?lang_cible=fon
// ** ne pas modifier le fichier **

return [

	// A
	'avis_conseil_selection_mot_cle' => 'gbɛta daxo :do ta ji ɔ, e nyɔ nu mi na cyan xota lɛ do gbɛ é lɔ mɛ',

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'titotɔ gblogbloji ɔ tɔn ',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'wiwlantɔ lɛ̂',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'Jonɔbatɔ gblogbloji ɔ tɔn whénu yé nɔ sɛ wɛn ɖo agun ɔ mɛ ɔ',

	// I
	'icone_creation_groupe_mots' => 'Mi ɖè àgùn wěkwin yɔyɔ dévó tɔn ',
	'icone_creation_mots_cles' => 'Mi ɖè gbètakɛn yɔyɔ dévó tɔn ',
	'icone_modif_groupe_mots' => 'mi vɔ ɖyɔ xóxòkplé lɛ',
	'icone_mots_cles' => 'gbètákɛn',
	'icone_supprimer_groupe_mots' => 'gbìɖí gbɛtá lɛ',
	'icone_voir_tous_mots_cles' => 'Mi kpɔn gbètákɛn lɛ bí',
	'info_articles_lies_mot' => 'wěmà é cáɖó àlɔ zíntɛn é lɔ lɛ wú',
	'info_changer_nom_groupe' => 'mi ɖyɔ nyíkɔ gbɛtá ɔ tɔn:',
	'info_creation_mots_cles' => 'mi bló bó sɔ gbètɛn lɛ sín àfɔɖóté',
	'info_dans_groupe' => 'ɖò àgun ɔ mɛ:',
	'info_delet_mots_cles' => 'àzán gùdó tɔn ', # MODIF
	'info_groupe_important' => 'Agùn trítrí',
	'info_mots_cles' => 'Gbètákɛn',
	'info_mots_cles_association' => 'Yè hɛn ɔ yè ná cá Gbètákɛn é lɔ àgùn élɔ mɛ ɔ :',
	'info_oui_suppression_mot_cle' => 'ŋ jó ná súnsún gbètákɛn bísésé.',
	'info_question_mots_cles' => 'Mi jó ná zán gbètákɛn à ?',
	'info_qui_attribue_mot_cle' => 'yé siwú sɔ gbètákɛn àgùn é lɔ tɔn ɖó :',
	'info_retirer_mot' => 'ɖè wékwí é lɔ sín ',
	'info_retirer_mots' => 'Mi ɖè wékwí bí sín ',
	'info_rubriques_liees_mot' => 'àkpáxwé lɛ ɖê bɔɖó gbètákɛn lɛ wú ɔ',
	'info_selection_un_seul_mot_cle' => 'Mi gbètákɛn ɖòkpó jɛn mi síwú zé.', # MODIF
	'info_supprimer_mot' => 'gbìdí  ɔ wékwín é lɔ ',
	'info_titre_mot_cle' => 'nyíkɔ xótá ɔ kàbí gbètákɛn ɔ tɔn ',
	'info_un_mot' => 'xókwín ɖòkpó',
	'item_ajout_mots_cles' => 'Mi sɔ gbètakɛn lɛ gɔná',
	'item_non_ajout_mots_cles' => 'mi má sɔ zán xógbè lɛ ɖò kplékplé ɔ mɛ wó',
	'item_non_utiliser_config_groupe_mots_cles' => 'mi vlɔn kàn nú bìbà sɔ yí Gblògblòjí bàɖémɛ jí ',
	'item_non_utiliser_mots_cles' => 'mi má zán gbètákɛn lɛ o',
	'item_utiliser_config_groupe_mots_cles' => 'mi zán xó kléwún lɛ',
	'item_utiliser_mots_cles' => 'mi zán xó kléwún lɛ',

	// L
	'logo_mot_cle' => 'sɔsí xógbè ɔ tɔn',

	// T
	'texte_config_groupe_mots_cles' => ' xógbè lɛ nyɔwlántɔ lɛ gblogblojí é lɔ nɔ zɔn bɔ mi nɔ sɛ  wɛn ɖó bó nɔ lɛ yí wɛnxó kléwun lɛ wěmà kléwún ɖé lɛ wɛbɔ yé nɔ zɔn bɔ xó lɛ nɔ yí àtɛjí gànmɛgànmɛmi sɔ xóxòkplégbàví mi tɔn ', # MODIF
	'texte_mots_cles' => 'Gbêgbè yé wlán wěmà ɔMi sɔ Azán ɖê yé sɔ wěmà sɔ xlɛàlɔwlí ɖévó lɛ ɖê gòsín gblogblojí é lɔ ján mi tìnmɛ càcàcàxójíjlá ɔmi sɔ ɖidé ɖó wěmà lɛ mɛsùpípù tɔn nú mi ná tò wěmà mi tɔn gànjí ɔ mi síwú zán kwín é lɔ lɛmi kó mɔ mi àmɔ mi sɔ ɖò xóxòkplégbàví ɔ mɛ ámi lɛ vɔ yí kànjí',
	'texte_mots_cles_dans_forum' => 'Gbêgbè yé wlán wěmà ɔMi sɔ Azán ɖê yé sɔ wěmà sɔ xlɛàlɔwlí ɖévó lɛ ɖê gòsín gblogblojí é lɔ ján mi tìnmɛ càcàcàxójíjlá ɔmi sɔ ɖidé ɖó wěmà lɛ mɛsùpípù tɔn nú mi ná tò wěmà mi tɔn gànjí ɔ mi síwú zán kwín é lɔ lɛ',
	'texte_nouveau_mot' => 'wékwín yɔyɔ',
	'titre_config_groupe_mots_cles' => 'tò gbètàkɛnxópklélɛ ',
	'titre_gauche_mots_edit' => 'Numɛló wěkwín ɔ tɔn :',
	'titre_mots_cles_dans_forum' => 'gbètákɛn é ɖò kplékplé gblogblojí ɔ tɔn mɛ',
	'titre_mots_tous' => 'gbètákɛn lɛ',
	'titre_nouveau_groupe' => 'àgùn yɔyɔ',
	'titre_page_mots_tous' => 'gbètákɛn',
];
